@@ -1,8 +1,8 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-# GetDevInfo Tests Package for DDRescue-GUI Version 1.7.2
+# GetDevInfo Tests Package for DDRescue-GUI
 # This file is part of DDRescue-GUI.
-# Copyright (C) 2013-2018 Hamish McIntyre-Bhatty
+# Copyright (C) 2013-2020 Hamish McIntyre-Bhatty
 # DDRescue-GUI is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3 or,
 # at your option, any later version.
@@ -14,8 +14,13 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with DDRescue-GUI.  If not, see <http://www.gnu.org/licenses/>.
-from __future__ import absolute_import
-from . import GetDevInfoTests
-from . import GetDevInfoTestData
-from . import BackendToolsTests
-from . import BackendToolsTestData
+
+"""
+This is the Tests package.
+"""
+
+from . import CoreToolsTests
+from . import CoreToolsTestData
+from . import CoreToolsTestFunctions
+
+from . import MountingToolsTests
